@@ -38,9 +38,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define GTK_OBJECT G_OBJECT
-#endif
 
 #include "pluma-commands.h"
 #include "pluma-debug.h"
@@ -230,6 +227,7 @@ do_find (PlumaSearchDialog *dialog,
 	gchar *search_text;
 	const gchar *entry_text;
 	gboolean match_case;
+        gboolean match_regex;
 	gboolean entire_word;
 	gboolean wrap_around;
 	gboolean search_backwards;
@@ -247,6 +245,7 @@ do_find (PlumaSearchDialog *dialog,
 	doc = PLUMA_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (active_view)));
 
 	match_case = pluma_search_dialog_get_match_case (dialog);
+        match_regex = pluma_search_dialog_get_match_regex(dialog);
 	entire_word = pluma_search_dialog_get_entire_word (dialog);
 	search_backwards = pluma_search_dialog_get_backwards (dialog);
 	wrap_around = pluma_search_dialog_get_wrap_around (dialog);
@@ -260,6 +259,7 @@ do_find (PlumaSearchDialog *dialog,
 
 	PLUMA_SEARCH_SET_CASE_SENSITIVE (flags, match_case);
 	PLUMA_SEARCH_SET_ENTIRE_WORD (flags, entire_word);
+        PLUMA_SEARCH_SET_MATCH_REGEX (flags, match_regex);
 
 	search_text = pluma_document_get_search_text (doc, &old_flags);
 
@@ -345,7 +345,9 @@ do_replace (PlumaSearchDialog *dialog,
 	gchar *unescaped_replace_text;
 	gchar *selected_text = NULL;
 	gboolean match_case;
+        gboolean match_regex;
 	gboolean parse_escapes;
+        gboolean need_refind;
 
 	doc = pluma_window_get_active_document (window);
 	if (doc == NULL)
@@ -375,17 +377,36 @@ do_replace (PlumaSearchDialog *dialog,
 			   NULL);
 
 	match_case = pluma_search_dialog_get_match_case (dialog);
+        match_regex = pluma_search_dialog_get_match_regex(dialog);
 
-	if ((selected_text == NULL) ||
-	    (match_case && (strcmp (selected_text, unescaped_search_text) != 0)) || 
-	    (!match_case && !g_utf8_caselessnmatch (selected_text,
-						    unescaped_search_text, 
-						    strlen (selected_text), 
-						    strlen (unescaped_search_text)) != 0))
+        if (selected_text != NULL)
+        {
+		if(!match_regex)
+		{
+		need_refind = (match_case && (strcmp (selected_text,unescaped_search_text) != 0))
+			       || (!match_case && !g_utf8_caselessnmatch (selected_text,
+                                                                          unescaped_search_text,
+                                                                          strlen (selected_text),
+                                                                          strlen (unescaped_search_text)) != 0);
+		}
+		else
+		{
+		need_refind = !g_regex_match_simple(unescaped_search_text,
+						    selected_text,
+						    match_case ? 0 : GTK_TEXT_SEARCH_CASE_INSENSITIVE ,
+						    0);
+		}
+	}
+	else
+	{
+		need_refind = TRUE;
+	}
+
+	if (need_refind)
 	{
 		do_find (dialog, window);
 		g_free (unescaped_search_text);
-		g_free (selected_text);	
+		g_free (selected_text);
 
 		return;
 	}
@@ -409,6 +430,7 @@ do_replace_all (PlumaSearchDialog *dialog,
 	const gchar *search_entry_text;
 	const gchar *replace_entry_text;
 	gboolean match_case;
+	gboolean match_regex;
 	gboolean entire_word;
 	gboolean parse_escapes;
 	guint flags = 0;
@@ -438,9 +460,11 @@ do_replace_all (PlumaSearchDialog *dialog,
 	g_return_if_fail ((replace_entry_text) != NULL);
 
 	match_case = pluma_search_dialog_get_match_case (dialog);
+    match_regex = pluma_search_dialog_get_match_regex(dialog);
 	entire_word = pluma_search_dialog_get_entire_word (dialog);
 
 	PLUMA_SEARCH_SET_CASE_SENSITIVE (flags, match_case);
+	PLUMA_SEARCH_SET_MATCH_REGEX (flags, match_regex);
 	PLUMA_SEARCH_SET_ENTIRE_WORD (flags, entire_word);
 
 	count = pluma_document_replace_all (doc, 
@@ -763,7 +787,7 @@ _pluma_cmd_search_goto_line (GtkAction   *action,
 	/* goto line is builtin in PlumaView, just activate
 	 * the corrisponding binding.
 	 */
-	gtk_bindings_activate (GTK_OBJECT (active_view),
+	gtk_bindings_activate (G_OBJECT (active_view),
 			       GDK_KEY_i,
 			       GDK_CONTROL_MASK);
 }
@@ -787,7 +811,7 @@ _pluma_cmd_search_incremental_search (GtkAction   *action,
 	/* incremental search is builtin in PlumaView, just activate
 	 * the corrisponding binding.
 	 */
-	gtk_bindings_activate (GTK_OBJECT (active_view),
+	gtk_bindings_activate (G_OBJECT (active_view),
 			       GDK_KEY_k,
 			       GDK_CONTROL_MASK);
 }
